# Taken from the fedora ruby-2.2.3 .spec. Thanks!

%global major_version 2
%global minor_version 2
%global teeny_version 8
%global major_minor_version %{major_version}.%{minor_version}

%global ruby_version %{major_minor_version}.%{teeny_version}
%global ruby_release %{ruby_version}

# Specify the named version. It has precedense to revision.
#%%global milestone rc1

# Keep the revision enabled for pre-releases from SVN.
#%%global revision 48936

%global ruby_archive %{name}-%{ruby_version}

# If revision and milestone are removed/commented out, the official release build is expected.
%if 0%{?milestone:1}%{?revision:1} != 0
%global development_release %{?milestone}%{?!milestone:%{?revision:r%{revision}}}
%global ruby_archive %{ruby_archive}-%{?milestone}%{?!milestone:%{?revision:r%{revision}}}
%endif


%define rel 1
%define subrel 1
%{!?release_string:%global release_string %mkrel %{?development_release:0.}%{rel}%{?development_release:.%{development_release}}}

%global rubygems_version 2.4.5.1

# The RubyGems library has to stay out of Ruby directory three, since the
# RubyGems should be share by all Ruby implementations.
%global rubygems_dir %{_datadir}/rubygems

# TODO: The IRB has strange versioning. Keep the Ruby's versioning ATM.
# http://redmine.ruby-lang.org/issues/5313
%global irb_version %{ruby_version}

%global bigdecimal_version 1.2.6
%global io_console_version 0.4.3
%global json_version 1.8.1.1
%global minitest_version 5.4.3
%global power_assert_version 0.2.2
%global psych_version 2.0.8.1
%global rake_version 10.4.2
%global rdoc_version 4.2.0
%global test_unit_version 3.0.8

# Might not be needed in the future, if we are lucky enough.
# https://bugzilla.redhat.com/show_bug.cgi?id=888262
%global tapset_root %{_datadir}/systemtap
%global tapset_dir %{tapset_root}/tapset
%global tapset_libdir %(echo %{_libdir} | sed 's/64//')*

%global _normalized_cpu %(echo %{_target_cpu} | sed 's/^ppc/powerpc/;s/i.86/i386/;s/sparcv./sparc/')

%global with_rubypick 1

# Additional defines by Mageia.

%define subver %{major_minor_version}
%define rubyapi %{subver}.0
%define rubyver %{ruby_version}

%define libname %mklibname ruby %{subver}

%define ruby_libdir %{_datadir}/%{name}
%define ruby_libarchdir %{_libdir}/%{name}

# This is the local lib/arch and should not be used for packaging.
%define ruby_sitelibdir %{_datadir}/ruby/site_ruby
%define ruby_sitearchdir %{_libdir}/ruby/site_ruby

# This is the general location for libs/archs compatible with all
# or most of the Ruby versions available in the Fedora repositories.
%define ruby_vendorlibdir %{_datadir}/ruby/vendor_ruby
%define ruby_vendorarchdir %{_libdir}/ruby/vendor_ruby

# The RubyGems library has to stay out of Ruby directory tree, since the
# RubyGems should be shared by all Ruby implementations.
%define gems_dir %{_datadir}/gems

%define bootstrap 0
%define build_gems 0

Summary:	Object Oriented Script Language
Name:		ruby
Version:	%{rubyver}
Release: 	%release_string
License:	Ruby or BSD
Group:		Development/Ruby
BuildRequires:	autoconf
BuildRequires:	byacc
BuildRequires:	doxygen
BuildRequires:	ncurses-devel
BuildRequires:	readline-devel
BuildRequires:	tcl-devel
BuildRequires:	tk-devel
BuildRequires:	db-devel
BuildRequires:  gdbm-devel >= 1.8.3
BuildRequires:  openssl-devel
BuildRequires:	zlib-devel
BuildRequires:	libffi-devel
BuildRequires:	yaml-devel
BuildRequires:	rpm-mageia-setup >= 1.158
Conflicts:	ruby-devel < 2.0.0.p451-4.mga5
Obsoletes:	ruby-rexml
Provides:	ruby-rexml
# Couldn't get the standalone gem to work
Provides:	rubygem(psych)
# explicit file provides (since such requires are automatically added by find-requires)
Provides: /usr/bin/ruby
Provides: ruby(abi) = %subver
Source0:	http://ftp.ruby-lang.org/pub/ruby/%{subver}/ruby-%{rubyver}.tar.xz
Source1:	operating_system.rb
Source3:	ruby.macros
# From FC:
# RPM dependency generators.
Source8: rubygems.attr
Source9: rubygems.req
Source10: rubygems.prov
URL:		http://ruby-lang.org/
%if !%bootstrap
BuildRequires:	ruby
%endif
%if !%bootstrap || %build_gems
Requires:	rubygems >= %{rubygems_version}
%endif

# == FEDORA PATCHES BEGINS ==
# http://bugs.ruby-lang.org/issues/7807
Patch0: ruby-2.1.0-Prevent-duplicated-paths-when-empty-version-string-i.patch
# Allows to override libruby.so placement. Hopefully we will be able to return
# to plain --with-rubyarchprefix.
# http://bugs.ruby-lang.org/issues/8973
Patch1: ruby-2.1.0-Enable-configuration-of-archlibdir.patch
# Force multiarch directories for i.86 to be always named i386. This solves
# some differencies in build between Fedora and RHEL.
Patch2: ruby-2.1.0-always-use-i386.patch
# Allows to install RubyGems into custom directory, outside of Ruby's tree.
# http://bugs.ruby-lang.org/issues/5617
Patch4: ruby-2.1.0-custom-rubygems-location.patch
# Make mkmf verbose by default
Patch5: ruby-1.9.3-mkmf-verbose.patch
# Adds support for '--with-prelude' configuration option. This allows to built
# in support for ABRT.
# http://bugs.ruby-lang.org/issues/8566
Patch6: ruby-2.1.0-Allow-to-specify-additional-preludes-by-configuratio.patch
# Use miniruby to regenerate prelude.c.
# https://bugs.ruby-lang.org/issues/10554
Patch7: ruby-2.2.3-Generate-preludes-using-miniruby.patch
# == FEDORA PATCHES ENDS ==
# operating_system.rb sets default_dir to user_dir for non root, this causes the build
# to install gems into user dir
Patch20: ruby-2.3.0-Do-not-install-to-user-dir.patch
Patch21: ruby-2.2.5-CVE-2016-7798.patch
# Patch22: ruby-2.0.0-tk2.6.patch
Patch23: ruby-2.2.5-npn_protocols.patch
Patch24: ruby-2.2.7-CVE-2016-2339.patch
Patch25: ruby-2.0.0-CVE-2015-9096.patch
Patch26: ruby-2.0.0-CVE-2016-2337.patch
Patch27: ruby-2.0.0-CVE-2017-17405.patch
Patch28: ruby-2.0.0-CVE-2017-17790.patch

%package	-n %{libname}
Summary:	Libraries necessary to run Ruby
Group:		Development/Ruby

%package	doc
Summary:	Documentation for the powerful language Ruby
Group:		Development/Ruby
BuildArch:	noarch

%package	devel
Summary:	Development file for the powerful language Ruby
Group:		Development/Ruby
Requires:	%{name} = %{version}
Requires:	%{libname} = %{version}

%package	tk
Summary:	Tk extension for the powerful language Ruby
Group:		Development/Ruby
Requires:	%{name} = %{version}

%package	RubyGems
Summary:	The Ruby standard for packaging ruby libraries
Group:		Development/Ruby
Version:	%{rubygems_version}
Requires:	ruby(abi) = %{subver}
Provides:	gem = %{rubygems_version}
Provides:	rubygems = %{rubygems_version}
Provides:	ruby(rubygems) = %{rubygems_version}
Conflicts:	rpm-mageia-setup-build < 1.159
BuildArch:	noarch

%define rake_ver %{rake_version}
%package	rake
Summary:	Simple ruby build program with capabilities similar to make
Group:		Development/Ruby
Version:	%{rake_ver}
Provides:	rubygem(rake) = %{rake_ver}
Requires:	ruby(abi) = %{subver}
BuildArch:	noarch

%define minitest_ver %{minitest_version}
%package	minitest
Summary:	Minitest provides a complete suite of testing facilities
Group:		Development/Ruby
Version:	%{minitest_ver}
License:	MIT
Provides:	rubygem(minitest) = %{minitest_ver}
Requires:	ruby(abi) = %{subver}
Requires:	ruby(rubygems) >= %{rubygems_version}
BuildArch:	noarch

%define power_assert_ver %{power_assert_version}
%package	power_assert
Summary:	Power Assert for Ruby
Group:		Development/Ruby
Version:	%{power_assert_ver}
License:	BSD
Provides:	rubygem(power_assert) = %{power_assert_ver}
Requires:	ruby(abi) = %{subver}
Requires:	ruby(rubygems) >= %{rubygems_version}
BuildArch:	noarch

%define json_ver %{json_version}
%package	json
Summary:	This is a JSON implementation as a Ruby extension in C
Group:		Development/Ruby
Version:	%{json_ver}
License:	Ruby or GPLv2
Provides:	rubygem(json) = %{json_ver}
Requires:	ruby(abi) = %{subver}
Requires:	ruby(rubygems) >= %{rubygems_version}

%define rdoc_ver %{rdoc_version}
%package	rdoc
Summary:	A tool to generate HTML and command-line documentation for Ruby projects
Group:		Development/Ruby
Version:	%{rdoc_ver}
License:	GPLv2 and Ruby and MIT
Provides:	rubygem(rdoc) = %{rdoc_ver}
Requires:	ruby(abi) = %{subver}
Requires:	ruby(rubygems) >= %{rubygems_version}
Requires:	ruby(irb) = %{version}
Provides:	rdoc = %{rdoc_ver}
Provides:	ri = %{rdoc_ver}
BuildArch:	noarch

%package	irb
Summary:	The Interactive Ruby
Group:		Development/Ruby
Provides:	irb = %{version}-%{release}
Provides:	ruby(irb) = %{version}-%{release}
Conflicts:	ruby < 1.9
BuildArch:	noarch

%define bigdecimal_ver %{bigdecimal_version}
%package	bigdecimal
Summary:	BigDecimal provides arbitrary-precision floating point decimal arithmetic
Group:		Development/Ruby
Version:	%{bigdecimal_ver}
License:	GPL+ or Artistic
Provides:	rubygem(bigdecimal) = %{bigdecimal_ver}
Requires:	ruby(abi) = %{subver}
Requires:	ruby(rubygems) >= %{rubygems_version}

%define io_console_ver %{io_console_version}
%package	io-console
Summary:	IO/Console is a simple console utilizing library
Group:		Development/Ruby
Version:	%{io_console_ver}
Provides:	rubygem(io-console) = %{io_console_ver}
Requires:	ruby(abi) = %{subver}
Requires:	ruby(rubygems) >= %{rubygems_version}

%define psych_ver %{psych_version}
%package psych
Summary:	A libyaml wrapper for Ruby
Version:	%{psych_ver}
Group:		Development/Ruby
License:	MIT
Provides:	rubygem(psych) = %{psych_ver}
Requires:	ruby(abi) = %{subver}
Requires:	ruby(rubygems) >= %{rubygems_version}
Conflicts:	ruby < 2.0.0

%define test_unit_ver %{test_unit_version}
%package test-unit
Summary:	test/unit compatible API testing framework
Version:	%{test_unit_ver}
Group:		Development/Ruby
License:	MIT
Provides:	rubygem(test-unit) = %{test_unit_ver}
Requires:	ruby(abi) = %{subver}
Requires:	ruby(rubygems) >= %{rubygems_version}
Conflicts:	ruby < 2.0.0
BuildArch:	noarch

%description
Ruby is the interpreted scripting language for quick and
easy object-oriented programming.  It has many features to
process text files and to do system management tasks (as in
Perl).  It is simple, straight-forward, and extensible.

%description	doc
Ruby is the interpreted scripting language for quick and
easy object-oriented programming.  It has many features to
process text files and to do system management tasks (as in
Perl). It is simple, straight-forward, and extensible.

This package contains the Ruby's documentation

%description	-n %{libname}
This package includes the libruby, necessary to run Ruby.

%description	devel
Ruby is the interpreted scripting language for quick and
easy object-oriented programming.  It has many features to
process text files and to do system management tasks (as in
Perl). It is simple, straight-forward, and extensible.

This package contains the Ruby's devel files.

%description	tk
Ruby is the interpreted scripting language for quick and
easy object-oriented programming.  It has many features to
process text files and to do system management tasks (as in
Perl). It is simple, straight-forward, and extensible.

This package contains the Tk extension for Ruby.

%description	RubyGems
RubyGems is the Ruby standard for publishing and managing third party
libraries.

%description	rake
Rake is a Make-like program implemented in Ruby. Tasks and dependencies are
specified in standard Ruby syntax.

%description 	rdoc
RDoc produces HTML and command-line documentation for Ruby projects.  RDoc
includes the 'rdoc' and 'ri' tools for generating and displaying online
documentation.

%description	json
This is a implementation of the JSON specification according to RFC 4627.
You can think of it as a low fat alternative to XML, if you want to store
data to disk or transmit it over a network rather than use a verbose
markup language.

%description	minitest
minitest/unit is a small and incredibly fast unit testing framework.

minitest/spec is a functionally complete spec engine.

minitest/benchmark is an awesome way to assert the performance of your
algorithms in a repeatable manner.

minitest/mock by Steven Baker, is a beautifully tiny mock object
framework.

minitest/pride shows pride in testing and adds coloring to your test
output.

%description	power_assert
Power Assert shows each value of variables and method calls in the expression.
It is useful for testing, providing which value wasn't correct when the
condition is not satisfied.

%description	irb
The irb is acronym for Interactive Ruby.  It evaluates ruby expression
from the terminal.

%description	bigdecimal
Ruby provides built-in support for arbitrary precision integer arithmetic.
For example:

42**13 -> 1265437718438866624512

BigDecimal provides similar support for very large or very accurate floating
point numbers. Decimal arithmetic is also useful for general calculation,
because it provides the correct answers people expect–whereas normal binary
floating point arithmetic often introduces subtle errors because of the
conversion between base 10 and base 2.

%description	io-console
IO/Console provides very simple and portable access to console. It doesn't
provide higher layer features, such like curses and readline.

%description	psych
Psych is a YAML parser and emitter. Psych leverages
libyaml[http://pyyaml.org/wiki/LibYAML] for its YAML parsing and emitting
capabilities. In addition to wrapping libyaml, Psych also knows how to
serialize and de-serialize most Ruby objects to and from the YAML format.

%description	test-unit
This library implements test/unit compatible API on minitest.
The test/unit means that test/unit which was bundled with Ruby 1.8.

%prep
%setup -q -n ruby-%{rubyver}
%autopatch -p1

%build
autoconf
CFLAGS=`echo %optflags | sed 's/-fomit-frame-pointer//'`
%configure2_5x --enable-shared --disable-rpath --enable-pthread \
        --enable-multiarch \
        --with-rubylibprefix='%{ruby_libdir}' \
        --with-archlibdir='%{_libdir}' \
        --with-rubyarchprefix='%{ruby_libarchdir}' \
        --with-sitedir='%{ruby_sitelibdir}' \
        --with-sitearchdir='%{ruby_sitearchdir}' \
        --with-vendordir='%{ruby_vendorlibdir}' \
        --with-vendorarchdir='%{ruby_vendorarchdir}' \
        --with-rubyhdrdir='%{_includedir}' \
        --with-rubyarchhdrdir='%{_includedir}' \
        --with-sitearchhdrdir='$(sitehdrdir)/$(arch)' \
        --with-vendorarchhdrdir='$(vendorhdrdir)/$(arch)' \
        --with-rubygemsdir='%{rubygems_dir}' \
        --with-ruby-pc='%{name}.pc' \
        --enable-multiarch \
        --with-ruby-version=''
%make

%install
%makeinstall_std install-doc

install -d %buildroot%{_datadir}/emacs/site-lisp
cp -a misc/ruby-mode.el %buildroot%{_datadir}/emacs/site-lisp

install -d %buildroot%{_sysconfdir}/emacs/site-start.d
cat <<EOF >%buildroot%{_sysconfdir}/emacs/site-start.d/%{name}.el
(autoload 'ruby-mode "ruby-mode" "Ruby editing mode." t)
(add-to-list 'auto-mode-alist '("\\\\.rb$" . ruby-mode))
(add-to-list 'interpreter-mode-alist '("ruby" . ruby-mode))
EOF

# Install the rpm macros
mkdir -p %buildroot%{_sysconfdir}/rpm/macros.d
cp %{SOURCE3} %buildroot%{_sysconfdir}/rpm/macros.d

# Install dependency generators.
mkdir -p %{buildroot}%{_rpmconfigdir}/fileattrs
install -m 644 %{SOURCE8} %{buildroot}%{_rpmconfigdir}/fileattrs
install -m 755 %{SOURCE9} %{buildroot}%{_rpmconfigdir}
install -m 755 %{SOURCE10} %{buildroot}%{_rpmconfigdir}

# Install custom operating_system.rb
mkdir -p %{buildroot}%{rubygems_dir}/rubygems/defaults
cp %{SOURCE1} %{buildroot}%{rubygems_dir}/rubygems/defaults

# Version is empty if --with-ruby-version is specified.
# http://bugs.ruby-lang.org/issues/7807
sed -i 's/Version: .*/Version: %{rubyver}/' %{buildroot}%{_libdir}/pkgconfig/%{name}.pc

rm -f %{buildroot}%{gems_dir}/cache/{minitest,power_assert,test-unit}-*.gem

# drop gems if not wanted, so that we could split them out as seperated source rpm
%if !%build_gems
rm -f %{buildroot}%{_bindir}/{rake,rdoc,ri,testrb}
rm -f %{buildroot}%{_mandir}/man1/{rake,ri}.*
rm -fr %{buildroot}%{ruby_libdir}/{minitest,rake,rdoc,json,bigdecimal}{,.rb}
rm -fr %{buildroot}%{ruby_libarchdir}/{json,bigdecimal.so}
rm -fr %{buildroot}%{gems_dir}/specifications/{minitest-%{minitest_version},default/rake-%{rake_version},default/rdoc-%{rdoc_version},default/json-%{json_version},default/bigdecimal-%{bigdecimal_version},default/psych-%{psych_version}}.gemspec
rm -fr %{buildroot}%{gems_dir}/gems/{minitest-%{minitest_version},rake-%{rake_version},rdoc-%{rdoc_version}}
%if !%bootstrap
rm -f %{buildroot}%{_bindir}/gem
rm -fr %{buildroot}%{rubygems_dir}/rbconfig
rm -fr %{buildroot}%{rubygems_dir}/rubygems
rm -f %{buildroot}%{rubygems_dir}/rubygems.rb
rm -f %{buildroot}%{rubygems_dir}/ubygems.rb
%endif
%endif

%check
make test

%files
%{_bindir}/erb
%{_bindir}/ruby
%dir %{ruby_libdir}
%{ruby_libdir}/*.rb
%exclude %{ruby_libdir}/irb.rb
%exclude %{ruby_libdir}/multi-tk.rb
%exclude %{ruby_libdir}/remote-tk.rb
%exclude %{ruby_libdir}/tcltk.rb
%exclude %{ruby_libdir}/tk.rb
%exclude %{ruby_libdir}/tkafter.rb
%exclude %{ruby_libdir}/tkbgerror.rb
%exclude %{ruby_libdir}/tkcanvas.rb
%exclude %{ruby_libdir}/tkclass.rb
%exclude %{ruby_libdir}/tkconsole.rb
%exclude %{ruby_libdir}/tkdialog.rb
%exclude %{ruby_libdir}/tkentry.rb
%exclude %{ruby_libdir}/tkfont.rb
%exclude %{ruby_libdir}/tkmacpkg.rb
%exclude %{ruby_libdir}/tkmenubar.rb
%exclude %{ruby_libdir}/tkmngfocus.rb
%exclude %{ruby_libdir}/tkpalette.rb
%exclude %{ruby_libdir}/tkscrollbox.rb
%exclude %{ruby_libdir}/tktext.rb
%exclude %{ruby_libdir}/tkvirtevent.rb
%exclude %{ruby_libdir}/tkwinpkg.rb
%{ruby_libdir}/cgi
%{ruby_libdir}/digest
%{ruby_libdir}/drb
%{ruby_libdir}/fiddle
%{ruby_libdir}/matrix
%{ruby_libdir}/net
%{ruby_libdir}/openssl
%{ruby_libdir}/optparse
%{ruby_libdir}/psych
%{ruby_libdir}/racc
%{ruby_libdir}/rbconfig
%{ruby_libdir}/rexml
%{ruby_libdir}/rinda
%{ruby_libdir}/ripper
%{ruby_libdir}/rss
%{ruby_libdir}/shell
%{ruby_libdir}/syslog
%{ruby_libdir}/unicode_normalize/normalize.rb
%{ruby_libdir}/unicode_normalize/tables.rb
%{ruby_libdir}/unicode_normalize.rb
%{ruby_libdir}/uri
%{ruby_libdir}/webrick
%{ruby_libdir}/xmlrpc
%{ruby_libdir}/yaml
%dir %{ruby_libarchdir}
%{ruby_libarchdir}/continuation.so
%{ruby_libarchdir}/coverage.so
%{ruby_libarchdir}/date_core.so
%{ruby_libarchdir}/dbm.so
%dir %{ruby_libarchdir}/digest
%{ruby_libarchdir}/digest.so
%{ruby_libarchdir}/digest/*.so
%dir %{ruby_libarchdir}/enc
%{ruby_libarchdir}/enc/*.so
%dir %{ruby_libarchdir}/enc/trans
%{ruby_libarchdir}/enc/trans/*.so
%{ruby_libarchdir}/etc.so
%{ruby_libarchdir}/fcntl.so
%{ruby_libarchdir}/fiber.so
%{ruby_libarchdir}/fiddle.so
%{ruby_libarchdir}/gdbm.so
%dir %{ruby_libarchdir}/io
%{ruby_libarchdir}/io/nonblock.so
%{ruby_libarchdir}/io/wait.so
%dir %{ruby_libarchdir}/mathn
%{ruby_libarchdir}/mathn/*.so
%{ruby_libarchdir}/nkf.so
%{ruby_libarchdir}/objspace.so
%{ruby_libarchdir}/openssl.so
%{ruby_libarchdir}/psych.so
%{ruby_libarchdir}/pathname.so
%{ruby_libarchdir}/pty.so
%dir %{ruby_libarchdir}/racc
%{ruby_libarchdir}/racc/*.so
%{ruby_libarchdir}/rbconfig.rb
%{ruby_libarchdir}/rbconfig/sizeof.so
%{ruby_libarchdir}/readline.so
%{ruby_libarchdir}/ripper.so
%{ruby_libarchdir}/sdbm.so
%{ruby_libarchdir}/socket.so
%{ruby_libarchdir}/stringio.so
%{ruby_libarchdir}/strscan.so
%{ruby_libarchdir}/syslog.so
%{ruby_libarchdir}/thread.so
%{ruby_libarchdir}/zlib.so
%{_mandir}/man1/erb.1.*
%{_mandir}/man1/ruby.1.*
%{_datadir}/emacs/site-lisp/*
%config(noreplace) %{_sysconfdir}/emacs/site-start.d/*
%{_sysconfdir}/rpm/macros.d/%{name}.macros
%{_datadir}/ruby/site_ruby
%{_libdir}/ruby/site_ruby
%{_datadir}/ruby/vendor_ruby
%{_libdir}/ruby/vendor_ruby
%if %bootstrap
%if !%build_gems
%{_bindir}/gem
%dir %{rubygems_dir}
%{rubygems_dir}/rbconfig
%{rubygems_dir}/rubygems
%{rubygems_dir}/rubygems.rb
%{rubygems_dir}/ubygems.rb
%endif
%endif
%{_rpmconfigdir}/fileattrs/rubygems.attr
%{_rpmconfigdir}/rubygems.req
%{_rpmconfigdir}/rubygems.prov

%files doc
%{_datadir}/ri
%{_datadir}/doc/ruby

%files -n %{libname}
%{_libdir}/libruby.so.%{subver}
%{_libdir}/libruby.so.%{rubyapi}

%files devel
%{_includedir}/*
%{_libdir}/libruby-static.a
%{_libdir}/libruby.so
%{_libdir}/pkgconfig/*.pc

%files tk
%{ruby_libarchdir}/tcltklib.so
%{ruby_libarchdir}/tkutil.so
%{ruby_libdir}/multi-tk.rb
%{ruby_libdir}/remote-tk.rb
%{ruby_libdir}/tcltk.rb
%{ruby_libdir}/tk.rb
%{ruby_libdir}/tkafter.rb
%{ruby_libdir}/tkbgerror.rb
%{ruby_libdir}/tkcanvas.rb
%{ruby_libdir}/tkclass.rb
%{ruby_libdir}/tkconsole.rb
%{ruby_libdir}/tkdialog.rb
%{ruby_libdir}/tkentry.rb
%{ruby_libdir}/tkfont.rb
%{ruby_libdir}/tkmacpkg.rb
%{ruby_libdir}/tkmenubar.rb
%{ruby_libdir}/tkmngfocus.rb
%{ruby_libdir}/tkpalette.rb
%{ruby_libdir}/tkscrollbox.rb
%{ruby_libdir}/tktext.rb
%{ruby_libdir}/tkvirtevent.rb
%{ruby_libdir}/tkwinpkg.rb
%{ruby_libdir}/tk
%{ruby_libdir}/tkextlib

%files irb
%{_bindir}/irb
%{ruby_libdir}/irb.rb
%{ruby_libdir}/irb
%{_mandir}/man1/irb.1*

%files power_assert
%{gems_dir}/gems/power_assert-%{power_assert_version}
%{gems_dir}/specifications/power_assert-%{power_assert_version}.gemspec

%files io-console
%{ruby_libdir}/io
%{ruby_libarchdir}/io/console.so
%{gems_dir}/specifications/default/io-console-%{io_console_version}.gemspec

%files test-unit
%{gems_dir}/gems/test-unit-*
%{gems_dir}/specifications/test-unit-%{test_unit_version}.gemspec

%if %build_gems
%files RubyGems
%{_bindir}/gem
%dir %{rubygems_dir}
%{rubygems_dir}/rbconfig
%{rubygems_dir}/rubygems
%{rubygems_dir}/rubygems.rb
%{rubygems_dir}/ubygems.rb

%files minitest
%{gems_dir}/gems/minitest-%{minitest_version}
%{gems_dir}/specifications/minitest-%{minitest_version}.gemspec

%files rake
%{_bindir}/rake
%{_mandir}/man1/rake.1.*
%{ruby_libdir}/rake
%{ruby_libdir}/rake.rb
%{gems_dir}/gems/rake-%{rake_version}
%{gems_dir}/specifications/default/rake-%{rake_version}.gemspec

%files rdoc
%{_bindir}/rdoc
%{_bindir}/ri
%{ruby_libdir}/rdoc
%{ruby_libdir}/rdoc.rb
%{gems_dir}/gems/rdoc-%{rdoc_version}
%{gems_dir}/specifications/default/rdoc-%{rdoc_version}.gemspec
%{_mandir}/man1/ri.1.*

%files json
%dir %{ruby_libarchdir}/json
%dir %{ruby_libarchdir}/json/ext
%{ruby_libarchdir}/json/ext/*.so
%{ruby_libdir}/json
%{gems_dir}/specifications/default/json-%{json_version}.gemspec

%files bigdecimal
%{ruby_libdir}/bigdecimal
%{ruby_libarchdir}/bigdecimal.so
%{gems_dir}/specifications/default/bigdecimal-%{bigdecimal_version}.gemspec

%files psych
%{ruby_libdir}/psych
%{ruby_libdir}/psych.rb
%{ruby_libarchdir}/psych.so
%{gems_dir}/specifications/default/psych-%{psych_version}.gemspec
%endif


%changelog
* Sat Dec 30 2017 luigiwalser <luigiwalser> 2.2.8-1.1.mga6
+ Revision: 1187964
- add patches from debian to fix CVE-2017-17405 and CVE-2017-17790

  + pterjan <pterjan>
    - Update gem versions
    - Update to 2.2.8 (CVE-2017-0898, CVE-2017-10784, CVE-2017-14033, CVE-2017-14064)
    - Update to latest 2.2.x
    - Add patches for CVE-2016-2339, CVE-2015-9096, CVE-2016-2337

* Sun Oct 09 2016 pterjan <pterjan> 2.2.5-15.mga6
+ Revision: 1059716
- Add patch for CVE-2016-7798

* Thu Sep 08 2016 luigiwalser <luigiwalser> 2.2.5-14.mga6
+ Revision: 1050451
- 2.2.5 (sync with f22)

* Thu Mar 03 2016 umeabot <umeabot> 2.2.4-13.mga6
+ Revision: 984820
- Rebuild for openssl

  + pterjan <pterjan>
    - Please perl-Youri-Package-RPM-Updater

* Tue Dec 29 2015 pterjan <pterjan> 2.2.4-12.mga6
+ Revision: 916704
- Bump release for subpackages which did not change version :(
- Update to 2.2.4
- Rever the io-console change, separate gem is older
- Don't ship io-console, we have a separate package

* Sat Dec 19 2015 pterjan <pterjan> 2.2.3-11.mga6
+ Revision: 912333
- Do not ship rake.rb, rdoc.rb and psych.rb in main package

* Sun Nov 01 2015 pterjan <pterjan> 2.2.3-10.mga6
+ Revision: 897270
- Ship all subpackages that are not packages separately

* Sat Oct 24 2015 pterjan <pterjan> 2.2.3-9.mga6
+ Revision: 895045
- Fix dependencies and disable gem subpackages

* Fri Oct 23 2015 pterjan <pterjan> 2.2.3-8.mga6
+ Revision: 894524
- Avoid file conflicts

* Fri Oct 23 2015 pterjan <pterjan> 2.2.3-7.mga6
+ Revision: 894486
- Force provides
- Provide the same ruby(abi) that we require

* Fri Oct 23 2015 pterjan <pterjan> 2.2.3-6.mga6
+ Revision: 894469
- Rebuild 2/2 to get proper dependencies

* Fri Oct 23 2015 pterjan <pterjan> 2.2.3-5.mga6
+ Revision: 894465
- Rebuild 1/2 to get proper dependencies
- Update gems path in the dependency extractor

* Fri Oct 23 2015 pterjan <pterjan> 2.2.3-4.mga6
+ Revision: 894460
- re enable bootstrap
- use the defined release_string macro (and fix it)
- build gems to allow bootstrap
- various fixes and cleanups, not yet tested if more are needed

  + blino <blino>
    - rebuild with bootstrap since RubyGems should be installable again

* Fri Oct 23 2015 blino <blino> 2.2.3-2.mga6
+ Revision: 894369
- remove gems cache (build was failing only in bootstrap mode before, now fails everytime since we do not install bundles in removed home dir anymore)
- stop removing gem dir in home now that all install paths should be ok
- update do-not-install-to-user-dir to handle bundle gems as well
- rebuild in bootstrap mode to be able to rebuild ruby-json which is required by ruby-RubyGems and thus ruby

  + pterjan <pterjan>
    - Fix file list
    - Fix regex

* Wed Oct 21 2015 shlomif <shlomif> 2.2.3-1.mga6
+ Revision: 893775
- New version 2.2.3 - synced in part from Fedora.

  + pterjan <pterjan>
    - Fix dependency extraction
    - Better patch fix for bootstrap

* Sat Oct 17 2015 pterjan <pterjan> 2.0.0.p645-5.mga6
+ Revision: 892281
- Define gems_dir in ruby package as it is used in rubygems.attr and we don't require Rubygems in bootstrap mode

* Fri Oct 16 2015 pterjan <pterjan> 2.0.0.p645-4.mga6
+ Revision: 892256
- fix user-dir patch to work in bootstrap

* Sun Oct 11 2015 pterjan <pterjan> 2.0.0.p645-3.mga6
+ Revision: 889596
- Add upstream patch to support Tk 8.6

  + tv <tv>
    - rebuild for tk 8.6

  + daviddavid <daviddavid>
    - rebuild for new tcl/tk 8.6.4

* Thu Apr 30 2015 pterjan <pterjan> 2.0.0.p645-1.mga5
+ Revision: 820881
- Drop applied patch
- Update to p645 (CVE-2015-1855)

* Fri Nov 14 2014 pterjan <pterjan> 2.0.0.p598-1.mga5
+ Revision: 796908
- Update to 2.0.0-p598 (CVE-2014-8090)

  + luigiwalser <luigiwalser>
    - add upstream patch to fix CVE-2014-4975

* Mon Oct 27 2014 pterjan <pterjan> 2.0.0.p594-1.mga5
+ Revision: 793866
- 2.0.0-p594 (CVE-2014-8080 + Insecure SSL/TLS options are now turn off by default + many bug fixes)

* Wed Oct 15 2014 umeabot <umeabot> 2.0.0.p451-6.mga5
+ Revision: 748136
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.0.0.p451-5.mga5
+ Revision: 688736
- Mageia 5 Mass Rebuild

* Thu Sep 11 2014 tv <tv> 2.0.0.p451-4.mga5
+ Revision: 674762
- move rubygem req/prov generator in ruby instead of -devel subpackage
  (this one is actually required by gems but not always -devel)

* Mon Sep 08 2014 tv <tv> 2.0.0.p451-3.mga5
+ Revision: 673709
- add RPM dependency generators for RubyGems

* Mon Apr 21 2014 pterjan <pterjan> 2.0.0.p451-2.mga5
+ Revision: 617250
- Fix version in pkg-config file (mga#13240)

* Mon Mar 10 2014 pterjan <pterjan> 2.0.0.p451-1.mga5
+ Revision: 601635
- Add upstream patch to fix build with new readline
- Patch to force installing bundled gems to system directory even if build is running as user
- Drop patch already applied
- Add fedora patch preventing potential multilib conflict
- Update to p451

* Fri Dec 27 2013 pterjan <pterjan> 2.0.0.p247-8.mga4
+ Revision: 560987
- Fix use of wrong macro now that they are different
- Move rubygems out of gems dir as this brakes bundler

* Sat Nov 23 2013 fwang <fwang> 2.0.0.p247-7.mga4
+ Revision: 552441
- add upstream patch to fix CVE-2013-4164

* Mon Oct 21 2013 umeabot <umeabot> 2.0.0.p247-6.mga4
+ Revision: 538717
- Mageia 4 Mass Rebuild

* Wed Oct 02 2013 fwang <fwang> 2.0.0.p247-5.mga4
+ Revision: 490240
- fix issues with DESTDIR (patch from fedora)

  + pterjan <pterjan>
    - Switch to Ruby 2
    - Grrr failed again

* Wed Aug 21 2013 fwang <fwang> 2.0.0.p247-4.mga4
+ Revision: 468908
- do not build bootstrap
- rebuild to drop temporary obsoletes
- temporarily obsolete newly built packages
- move into current


* Sun Dec 26 2010 Funda Wang <fwang@mandriva.org> 1.8.7.p330-1mdv2011.0
+ Revision: 625126
- new version 1.8.7-p330

* Sun Dec 19 2010 Rémy Clouard <shikamaru@mandriva.org> 1.8.7.p302-3mdv2011.0
+ Revision: 623192
- add ruby(abi) provides

* Wed Dec 01 2010 Funda Wang <fwang@mandriva.org> 1.8.7.p302-2mdv2011.0
+ Revision: 604336
- rebuild for new zlib

* Fri Aug 20 2010 Funda Wang <fwang@mandriva.org> 1.8.7.p302-1mdv2011.0
+ Revision: 571401
- new version 1.8.7 p302

* Fri Jul 09 2010 Funda Wang <fwang@mandriva.org> 1.8.7.p299-1mdv2011.0
+ Revision: 549887
- New version 1.8.7-p299 (drop merged patches)

* Fri Jun 18 2010 Pascal Terjan <pterjan@mandriva.org> 1.8.7.p249-4mdv2010.1
+ Revision: 548298
- Own doc dir in -doc package too, so that it gets removed (#59831)

* Mon Apr 05 2010 Funda Wang <fwang@mandriva.org> 1.8.7.p249-3mdv2010.1
+ Revision: 531719
- add arch patch to build with openssl 1.0.0
- rebuild for new openssl

* Fri Feb 26 2010 Oden Eriksson <oeriksson@mandriva.com> 1.8.7.p249-2mdv2010.1
+ Revision: 511635
- rebuilt against openssl-0.9.8m

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - fix annoying '`*' interpreted as argument prefix' warning with pathname (P4)

* Sun Jan 10 2010 Funda Wang <fwang@mandriva.org> 1.8.7.p249-1mdv2010.1
+ Revision: 488839
- new patch series p249

* Sun Jan 03 2010 Funda Wang <fwang@mandriva.org> 1.8.7.p248-1mdv2010.1
+ Revision: 486008
- 1.8.7-p248
- move patchversion into version tag, so that releases become real releases

* Fri Jan 01 2010 Oden Eriksson <oeriksson@mandriva.com> 1.8.7-10p174mdv2010.1
+ Revision: 484729
- rebuilt against bdb 4.8

* Tue Jun 16 2009 Frederik Himpe <fhimpe@mandriva.org> 1.8.7-9p174mdv2010.0
+ Revision: 386433
- Update to new version 1.8.7-p174

* Sat Jun 13 2009 Frederik Himpe <fhimpe@mandriva.org> 1.8.7-9p173mdv2010.0
+ Revision: 385730
- Update to new version 1.8.7-p173

* Tue May 12 2009 Frederik Himpe <fhimpe@mandriva.org> 1.8.7-9p160mdv2010.0
+ Revision: 374964
- Update to version 1.8.7-p160 (fixes CVE-2007-1558 and CVE-2008-1447)
- Remove patch for compilation with gcc 4.3: integrated upstream

* Thu Feb 26 2009 Pascal Terjan <pterjan@mandriva.org> 1.8.7-9p72mdv2009.1
+ Revision: 345172
- Rediff lib64 patch

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild for new libreadline

* Sat Dec 06 2008 Adam Williamson <awilliamson@mandriva.org> 1.8.7-8p72mdv2009.1
+ Revision: 311085
- rebuild for new tcl

* Thu Sep 11 2008 Pixel <pixel@mandriva.com> 1.8.7-7p72mdv2009.0
+ Revision: 283683
- explicitly provide /usr/bin/ruby
  (since such requires are automatically added by find-requires) (#42316)

* Wed Aug 13 2008 Frederik Himpe <fhimpe@mandriva.org> 1.8.7-6p72mdv2009.0
+ Revision: 271536
- Update ruby 1.8.7 to patchlevel 72 (fixes CVE-2008-1447,
  CVE-2008-3655, CVE-2008-3656, CVE-2008-3657)
- Remove CVE-2008-2376 patch: fix integrated upstream

* Thu Jul 10 2008 Gustavo De Nardin <gustavodn@mandriva.com> 1.8.7-5p22mdv2009.0
+ Revision: 233280
- 1.8.7-p22
  . security fixes for CVE-2008-2662, CVE-2008-2663, CVE-2008-2664,
    CVE-2008-2725, CVE-2008-2726
- P4: fix for CVE-2008-2376

* Tue Jun 10 2008 Pascal Terjan <pterjan@mandriva.org> 1.8.7-4p17mdv2009.0
+ Revision: 217724
- Filter -Wl,--no-undefined from CFLAGS used by mkmf

* Tue Jun 10 2008 Pascal Terjan <pterjan@mandriva.org> 1.8.7-3p17mdv2009.0
+ Revision: 217392
- Really fix archdir on x86_64

* Tue Jun 10 2008 Pascal Terjan <pterjan@mandriva.org> 1.8.7-2p17mdv2009.0
+ Revision: 217351
- Fix archdir on x86_64

* Tue Jun 10 2008 Pascal Terjan <pterjan@mandriva.org> 1.8.7-1p17mdv2009.0
+ Revision: 217304
- Add macros ruby_vendorarchdir and ruby_vendorlibdir
- Update to p17

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Mon Jun 09 2008 Pascal Terjan <pterjan@mandriva.org> 1.8.7-1mdv2009.0
+ Revision: 217004
- Enforce vendor_ruby in /usr/lib
- Add linux-gnu to search path
- 1.8.7
- Drop P2 and P26
- Update P0
- Enforce sitedir to be in /usr/lib

* Fri May 23 2008 Oden Eriksson <oeriksson@mandriva.com> 1.8.6-12p114mdv2009.0
+ Revision: 210416
- bump release

* Fri May 23 2008 Gustavo De Nardin <gustavodn@mandriva.com> 1.8.6-11p114mdv2009.0
+ Revision: 210214
- added ruby-1.8.6p114-mdv,svn-tk85-gcc43.patch: fix tk extension build for
  tcl/tk 8.5, required with GCC 4.3
- fixed use of host_os, which should be target_os, in files lists

  + Oden Eriksson <oeriksson@mandriva.com>
    - added a gcc43 patch from fedora

* Mon Mar 10 2008 Gustavo De Nardin <gustavodn@mandriva.com> 1.8.6-9p114mdv2008.1
+ Revision: 183218
- new patch version p114
- Patch3 (ruby-1.8.6-p111-rexml-trans) applied upstream
- made the patch version visible in the Release tag
- fixed License tag following policy

* Fri Feb 22 2008 Gustavo De Nardin <gustavodn@mandriva.com> 1.8.6-8mdv2008.1
+ Revision: 173813
- fixes a variable name in REXML code, pointed by Guillaume Cottenceau

* Mon Jan 28 2008 Gustavo De Nardin <gustavodn@mandriva.com> 1.8.6-7mdv2008.1
+ Revision: 159036
- updated to ruby-1.8.6-p111 (fixes CVE-2007-5162)
- removed Patch2 (ruby-rdoc_graphviz), fixed upstream a little differently
- removed Patch3 (rexml-double-encoding), applied upstream
- Patch2 (CVE-2007-5770 fix), from Suse, minus CVE-2007-5162 fixes; ruby
  1.8.6 doesn't seem to have SSL support in smtp.rb and pop.rb
- -doc subpackage doesn't requires main package

* Fri Dec 21 2007 Oden Eriksson <oeriksson@mandriva.com> 1.8.6-6mdv2008.1
+ Revision: 136344
- rebuilt against new build deps

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Fri Sep 07 2007 Anssi Hannula <anssi@mandriva.org> 1.8.6-5mdv2008.0
+ Revision: 82045
- rebuild for new soname of tcl

* Thu Jun 07 2007 Guillaume <gc@mandriva.com> 1.8.6-4mdv2008.0
+ Revision: 36514
- add patch3: Fix REXML wrongly saving XML special chars as doubly escaped entities

  + Pascal Terjan <pterjan@mandriva.org>
    - Be more consistant in the macros

  + Nicolas Lécureuil <nlecureuil@mandriva.com>
    - Remove double BR

* Mon Apr 23 2007 Nicolas Lécureuil <nlecureuil@mandriva.com> 1.8.6-3mdv2008.0
+ Revision: 17162
- Fix BuildRequires (tk-devel instead of libx11-devel)

* Sun Apr 22 2007 Pascal Terjan <pterjan@mandriva.org> 1.8.6-2mdv2008.0
+ Revision: 16751
- BuildRequires libx11-devel until tk-devel get fixed
- Use Development/Ruby group
- Fix the dot -V parsing in rdoc for recent graphviz


* Sat Apr 07 2007 Pascal Terjan <pterjan@mandriva.org> 1.8.6-1mdv2007.1
+ Revision: 151012
- 1.8.6
- drop p3 and p4
- uncompress and update p0 and p1

* Mon Dec 18 2006 Gustavo De Nardin <gustavodn@mandriva.com> 1.8.5-5mdv2007.1
+ Revision: 98532
- Mostly build changes:
- dependencies fixes
  . don't need full XFree86-devel, tcl/tk devel packages should be enough
  . add missing zlib1-devel BuildRequires, which before was probably being
    provided indirectly by XFree86-devel
- avoid use of non-ascii chars in spec (parameter separator for sed command)
- avoid implicitly requiring Perl for build (for filtering devel and tk
  files)
- use file lists instead of shell loops for fixing permissions, for shorter
  build time

* Wed Dec 06 2006 Pascal Terjan <pterjan@mandriva.org> 1.8.5-4mdv2007.1
+ Revision: 91863
- CVE-2006-6303

* Mon Oct 30 2006 Pascal Terjan <pterjan@mandriva.org> 1.8.5-3mdv2007.1
+ Revision: 73677
- CVE-2006-5467
- Import ruby

* Tue Sep 19 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 1.8.5-2mdv2007.0
- Rebuild

* Sat Aug 26 2006 Pascal Terjan <pterjan@mandriva.org> 1.8.5-1mdv2007.0
- 1.8.5
- Drop P2, P3, P4, P5, P6

* Wed Aug 23 2006 Pascal Terjan <pterjan@mandriva.org> 1.8.4-7mdv2007.0
- CVE-2006-3694 (P4, P5, P6)
- Fix macros in changelog
- Move make test into %%check

* Sun Jul 16 2006 Guillaume Cottenceau 1.8.4-6mdv2007.0
- author patch3 since even ruby authors don't care to ship a badly broken
  rexml for several months

* Sat May 20 2006 Laurent MONTEL <lmontel@mandriva.com> 1.8.4-5
- Add patch2 (patch from opensuse): don't redefine eaccess (it's into new glibc)

* Thu Mar 09 2006 Pascal Terjan <pterjan@mandriva.org> 1.8.4-4mdk
- BuildRequire openssl-devel

* Tue Feb 14 2006 Pascal Terjan <pterjan@mandriva.org> 1.8.4-3mdk
- Move /etc/rpm/ruby.macros to main package. It is required to build a lot
  of noarch package which do not need -devel.

* Thu Feb 09 2006 Pascal Terjan <pterjan@mandriva.org> 1.8.4-2mdk
- Provide /etc/rpm/ruby.macros with usual macros

* Fri Jan 27 2006 Pascal Terjan <pterjan@mandriva.org> 1.8.4-1mdk
- 1.8.4
- Update P0

* Tue Jan 03 2006 Oden Eriksson <oeriksson@mandriva.com> 1.8.3-5mdk
- rebuilt against soname aware deps (tcl/tk)
- fix deps
- enable threading (--enable-pthread)

* Sun Nov 13 2005 Oden Eriksson <oeriksson@mandriva.com> 1.8.3-4mdk
- rebuilt against openssl-0.9.8a

* Fri Nov 04 2005 Michael Scherer <misc@mandriva.org> 1.8.3-3mdk
- mkrel

* Thu Oct 06 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 1.8.3-2mdk
- ppc64 fixes

* Sat Oct 01 2005 Pascal Terjan <pterjan@mandriva.org> 1.8.3-1mdk
- 1.8.3
- Drop P2
- Update P1
- Fix requires-on-release

* Wed Jul 13 2005 Pascal Terjan <pterjan@mandriva.org> 1.8.2-7mdk
- CAN-2005-1992 (P2)
- Fix interpreter and rights on samples

* Thu Mar 31 2005 Pascal Terjan <pterjan@mandrake.org> 1.8.2-6mdk
- put and search everything in %%{_prefix}/lib/ruby/ even on x86_64, else all
  noarch packages won't work

* Fri Jan 21 2005 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 1.8.2-5mdk
- rebuild for new readline

* Tue Jan 18 2005 Gtz Waschk <waschk@linux-mandrake.com> 1.8.2-4mdk
- force build with libgdbm3

* Sat Jan 15 2005 Pixel <pixel@mandrakesoft.com> 1.8.2-3mdk
- add ri doc (bugzilla #12976)

* Sun Jan 02 2005 Pascal Terjan <pterjan@mandrake.org> 1.8.2-2mdk
- Disable rpath

* Fri Dec 31 2004 Pascal Terjan <pterjan@mandrake.org> 1.8.2-1mdk
- 1.8.2

* Wed Dec 08 2004 Götz Waschk <waschk@linux-mandrake.com> 1.8.1-5mdk
- rebuild for libgdbm3

* Tue Aug 31 2004 Götz Waschk <waschk@linux-mandrake.com> 1.8.1-4mdk
- build with db 4.2

* Tue Jun 29 2004 Christiaan Welvaart <cjw@daneel.dyndns.org> 1.8.1-2mdk
- BuildRequires: tcl

